@@ -37,17 +37,6 @@ from heatclient.openstack.common._i18n import _
 from heatclient.openstack.common._i18n import _LI
 
 
-def _authenticated_fetcher(client):
-    def _do(*args, **kwargs):
-        if isinstance(client.http_client, http.SessionClient):
-            method, url = args
-            return client.http_client.request(url, method, **kwargs).content
-        else:
-            return client.http_client.raw_request(*args, **kwargs).content
-
-    return _do
-
-
 class CreateStack(show.ShowOne):
     """Create a stack."""
 
@@ -136,7 +125,7 @@ class CreateStack(show.ShowOne):
 
         tpl_files, template = template_utils.process_template_path(
             parsed_args.template,
-            object_request=_authenticated_fetcher(client))
+            object_request=http.authenticated_fetcher(client))
 
         env_files, env = (
             template_utils.process_multiple_environments_and_files(
@@ -297,7 +286,7 @@ class UpdateStack(show.ShowOne):
 
         tpl_files, template = template_utils.process_template_path(
             parsed_args.template,
-            object_request=_authenticated_fetcher(client),
+            object_request=http.authenticated_fetcher(client),
             existing=parsed_args.existing)
 
         env_files, env = (
@@ -653,6 +642,9 @@ class DeleteStack(command.Command):
             except heat_exc.HTTPNotFound:
                 failure_count += 1
                 print(_('Stack not found: %s') % sid)
+            except heat_exc.Forbidden:
+                failure_count += 1
+                print(_('Forbidden: %s') % sid)
 
         if parsed_args.wait:
             for sid, marker in stacks_waiting:
@@ -859,7 +851,17 @@ class OutputShowStack(show.ShowOne):
         except heat_exc.HTTPNotFound:
             msg = _('Stack %(id)s or output %(out)s not found.') % {
                 'id': parsed_args.stack, 'out': parsed_args.output}
-            raise exc.CommandError(msg)
+            try:
+                output = None
+                stack = client.stacks.get(parsed_args.stack).to_dict()
+                for o in stack.get('outputs', []):
+                    if o['output_key'] == parsed_args.output:
+                        output = o
+                        break
+                if output is None:
+                    raise exc.CommandError(msg)
+            except heat_exc.HTTPNotFound:
+                raise exc.CommandError(msg)
 
         if 'output_error' in output:
             msg = _('Output error: %s') % output['output_error']
@@ -895,8 +897,12 @@ class OutputListStack(lister.Lister):
         try:
             outputs = client.stacks.output_list(parsed_args.stack)['outputs']
         except heat_exc.HTTPNotFound:
-            msg = _('Stack not found: %s') % parsed_args.stack
-            raise exc.CommandError(msg)
+            try:
+                outputs = client.stacks.get(
+                    parsed_args.stack).to_dict()['outputs']
+            except heat_exc.HTTPNotFound:
+                msg = _('Stack not found: %s') % parsed_args.stack
+                raise exc.CommandError(msg)
 
         columns = ['output_key', 'description']
 
